@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import logging
 import os
-import typing
+from typing import Optional
 
 LOGGER = logging.getLogger(__name__)
 
@@ -28,31 +28,31 @@ def is_in_aliyun():
     return os.path.exists('/usr/sbin/aliyun-service')
 
 
-def get_str(key: str, default_value: str = None) -> typing.Optional[str]:
-    return os.getenv(key) or default_value
+def get_str(key: str, default: str = None) -> Optional[str]:
+    return os.getenv(key) or default
 
 
-def get_int(key: str, default_value: int = None) -> typing.Optional[int]:
-    return get_of_type(key, int, default_value)
+def get_int(key: str, default: int = None) -> Optional[int]:
+    return get_of_type(key, int, default)
 
 
-def get_float(key: str, default_value: float = None) -> typing.Optional[float]:
-    return get_of_type(key, float, default_value)
+def get_float(key: str, default: float = None) -> Optional[float]:
+    return get_of_type(key, float, default)
 
 
-def get_bool(key: str, default_value: str = None) -> typing.Optional[bool]:
-    return get_of_type(key, bool, default_value)
+def get_bool(key: str, default: str = None) -> Optional[bool]:
+    return get_of_type(key, bool, default)
 
 
-def get_complex(key: str, default_value: complex = None) -> typing.Optional[complex]:
-    return get_of_type(key, complex, default_value)
+def get_complex(key: str, default: complex = None) -> Optional[complex]:
+    return get_of_type(key, complex, default)
 
 
-def get_of_type(key: str, of_type: type, default_value):
+def get_of_type(key: str, of_type: type, default=None):
     value = os.getenv(key)
     if value is not None:
         try:
             return of_type(value)
         except ValueError as err:
             LOGGER.warning(str(err))
-    return default_value
+    return default
