@@ -59,9 +59,9 @@ for msg in consumer:
 import typing
 
 from kafka import KafkaConsumer, KafkaProducer
-from kafka.errors import NoBrokersAvailable, KafkaTimeoutError
+from kafka.errors import KafkaTimeoutError, NoBrokersAvailable
 
-from . import logs, config, jsons
+from . import config, jsons, logs
 
 LOGGER = logs.get_logger(__name__)
 
@@ -76,6 +76,12 @@ class Kafka(object):
             raise ValueError(f'no config found for kafka, expecting: `kafka.{self.profile}`')
         self._producer = None
 
+    def __str__(self) -> str:
+        return f"hosts: {self._conf.get('hosts')}, group_id: {self._conf.get('group_id')}"
+
+    def __repr__(self) -> str:
+        return self.__str__()
+
     def get_consumer(self,
                      topic: typing.Union[str, list],
                      enable_auto_commit=False,
@@ -108,7 +114,7 @@ class Kafka(object):
             )
         return self._producer
 
-    def publish(self, topic, message, flush: bool = True):
+    def publish(self, topic, message, key=None, headers=None, partition=None, timestamp_ms=None, flush: bool = False):
         message_type = type(message)
         if message_type == str:
             payload = message.encode()
@@ -120,7 +126,7 @@ class Kafka(object):
         try:
             LOGGER.debug(f"sending payload: {payload}")
             producer = self.get_producer()
-            future = producer.send(topic, payload)
+            future = producer.send(topic, payload, key, headers, partition, timestamp_ms)
             if flush:
                 producer.flush(10)
             return future
