@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-import argparse
 import logging
 import os
 import sys
-from logging import handlers as logging_handlers
 import typing
+from logging import handlers as logging_handlers
 
-from . import paths, config, invoker
+from . import args, config, invoker, paths
 
 LOGGER_FORMAT = config.get('logger.format', "%(asctime)s %(levelname)-7s %(name)s:%(lineno)-4d - %(message)s")
 LOGGER_FORMATTER = logging.Formatter(LOGGER_FORMAT)
@@ -48,7 +47,15 @@ def _get_handlers():
                 print(f'logging to: {log_path} [{handler_name}]')
     else:
         if log_filename_arg:
-            log_path = paths.get(_LOGGER_DIR, log_filename_arg)
+            from datetime import datetime
+            params = {
+                'date': datetime.now().strftime('%y%m%d'),
+                'datehour': datetime.now().strftime('%y%m%d-%H'),
+                'datetime': datetime.now().strftime('%y%m%d-%H%M%S')
+            }
+            log_filename = log_filename_arg.format(**params)
+            log_path = paths.get(_LOGGER_DIR, log_filename)
+            paths.make_parent_dirs(log_path)
             handler = logging.FileHandler(log_path)
             handler.setFormatter(LOGGER_FORMATTER)
             _HANDLERS.append(handler)
@@ -84,10 +91,7 @@ def _updated_handler_args(handler_args: dict, log_filename_arg: str, log_filenam
 
 
 def _get_logger_filename_arg():
-    parser = argparse.ArgumentParser(prog='logs', add_help=False)
-    parser.add_argument('--log_filename', required=False)
-    args, _ = parser.parse_known_args()
-    return args.log_filename
+    return args.get_arg('log-to', help='abstract path or relative path to `{project-root}/data/logs`')
 
 
 def _get_logger_filename_fallback():
@@ -107,7 +111,7 @@ def get_logger(name=None, level=None):
         logger.setLevel(level)
 
     # update other modules that newly imported
-    for _name in logging.root.manager.loggerDict:
+    for _name in list(logging.root.manager.loggerDict):
         if _name not in _LOGGERS:
             _LOGGERS[_name] = _get_logger(_name)
 
