@@ -60,17 +60,22 @@ def normalize(
     for p, sub in SUB_NORMALIZE:
         text = p.sub(sub, text)
     try:
-        text = json.loads(f'"{text}"')
+        val = json.loads(f'"{text}"')
+        if isinstance(val, str):
+            text = val
     except json.JSONDecodeError:
         pass
     if controls:
         text = remove_control_chars(text)
     if specials:
-        text = unicodedata.normalize('NFKD', text)
+        text = unicodedata.normalize('NFD', text)
     if emoji:
         text = remove_emoji(text)
     if unicode:
-        text = codecs.decode(codecs.encode(text, 'latin-1', 'backslashreplace'), 'unicode-escape')
+        try:
+            text = codecs.decode(codecs.encode(text, 'latin-1', 'backslashreplace'), 'unicode-escape')
+        except UnicodeDecodeError:
+            pass
     if encoding:
         try:
             text = text.encode(encoding, 'ignore').decode(encoding, 'ignore')
@@ -143,7 +148,7 @@ def sha1(text: str, hexical: bool = True):
     if hexical:
         return hashlib.sha1(unique_key).hexdigest()
     else:
-        return base64.b64encode(hashlib.sha1(unique_key).digest())
+        return base64.b64encode(hashlib.sha1(unique_key).digest()).decode()
 
 
 def md5(text: str, hexical: bool = True):
@@ -154,7 +159,7 @@ def md5(text: str, hexical: bool = True):
     if hexical:
         return hashlib.md5(unique_key).hexdigest()
     else:
-        return base64.b64encode(hashlib.md5(unique_key).digest())
+        return base64.b64encode(hashlib.md5(unique_key).digest()).decode()
 
 
 def sim(a, b):
@@ -348,7 +353,7 @@ def is_invalid_chinese(text: str):
     :return: True if is Chinese is invalid
     """
     try:
-        text.encode('gb2312')
+        text.encode('gbk')
         return False
     except UnicodeEncodeError:
         return True
@@ -367,12 +372,8 @@ def pad(text: str, width: int, align: str = '<', fill: str = ' '):
     :param fill: char to fill the padding
     :return:
     """
-    return '{text:{fill}{align}{width}}'.format(
-        text=text or '',
-        fill=fill,
-        align=align,
-        width=width,
-    )
+    assert align in ('<', '^', '>')
+    return f"{text:{fill}{align}{width}}"
 
 
 def random(n: int) -> str:
